summaryrefslogtreecommitdiff
path: root/resources/jquery.ui/jquery.ui.dialog.js
diff options
context:
space:
mode:
Diffstat (limited to 'resources/jquery.ui/jquery.ui.dialog.js')
-rw-r--r--resources/jquery.ui/jquery.ui.dialog.js22
1 files changed, 5 insertions, 17 deletions
diff --git a/resources/jquery.ui/jquery.ui.dialog.js b/resources/jquery.ui/jquery.ui.dialog.js
index 33119af2..082bf2c0 100644
--- a/resources/jquery.ui/jquery.ui.dialog.js
+++ b/resources/jquery.ui/jquery.ui.dialog.js
@@ -1,7 +1,7 @@
/*
* jQuery UI Dialog 1.8.17
*
- * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2012, AUTHORS.txt (http://jqueryui.com/about)
* Dual licensed under the MIT or GPL Version 2 licenses.
* http://jquery.org/license
*
@@ -37,18 +37,6 @@ var uiDialogClasses =
maxWidth: true,
minHeight: true,
minWidth: true
- },
- // support for jQuery 1.3.2 - handle common attrFn methods for dialog
- attrFn = $.attrFn || {
- val: true,
- css: true,
- html: true,
- text: true,
- data: true,
- width: true,
- height: true,
- offset: true,
- click: true
};
$.widget("ui.dialog", {
@@ -397,7 +385,7 @@ $.widget("ui.dialog", {
if ( key === "click" ) {
return;
}
- if ( key in attrFn ) {
+ if ( key in button ) {
button[ key ]( value );
} else {
button.attr( key, value );
@@ -702,7 +690,7 @@ $.widget("ui.dialog", {
});
$.extend($.ui.dialog, {
- version: "1.8.17",
+ version: "1.8.23",
uuid: 0,
maxZ: 0,
@@ -1,7 +1,7 @@
-/*
- * jQuery UI Dialog 1.8.17
+/*!
+ * jQuery UI Dialog 1.8.23
*